@@ -3,6 +3,7 @@ In this module there're implementations & tests
 of general async handling features.
 */
 
+use std::error::Error;
 use std::sync::{
     atomic::{AtomicBool, Ordering},
     mpsc,
@@ -15,8 +16,6 @@ use std::time::Duration;
 use super::common::shared_thread_pool;
 #[cfg(feature = "for_futures")]
 use crate::futures::task::SpawnExt;
-// #[cfg(feature = "for_futures")]
-use std::error::Error;
 #[cfg(feature = "for_futures")]
 use std::future::Future;
 #[cfg(feature = "for_futures")]
@@ -86,6 +85,7 @@ pub trait Will<T>: Send + Sync + 'static {
     fn result(&mut self) -> Option<T>;
 }
 
+#[cfg(all(feature = "publisher", feature = "handler"))]
 #[derive(Clone)]
 pub struct WillAsync<T> {
     effect: Arc<Mutex<dyn FnMut() -> T + Send + Sync + 'static>>,
@@ -98,6 +98,7 @@ pub struct WillAsync<T> {
     waker: Arc<Mutex<Option<Waker>>>,
 }
 
+#[cfg(all(feature = "publisher", feature = "handler"))]
 impl<T> WillAsync<T> {
     pub fn new(effect: impl FnMut() -> T + Send + Sync + 'static) -> WillAsync<T> {
         Self::new_with_handler(effect, HandlerThread::new_with_mutex())
@@ -119,6 +120,7 @@ impl<T> WillAsync<T> {
     }
 }
 
+#[cfg(all(feature = "publisher", feature = "handler"))]
 impl<T> Will<T> for WillAsync<T>
 where
     T: Clone + Send + Sync + 'static,
@@ -206,7 +208,7 @@ where
     }
 }
 
-#[cfg(feature = "for_futures")]
+#[cfg(all(feature = "for_futures", feature = "publisher", feature = "handler"))]
 impl<T> Future for WillAsync<T>
 where
     T: Clone + Send + Sync + 'static,
